@@ -205,7 +205,13 @@ option_delete = Option(
 
 # Typer options to control git-related operations
 option_rev = Option(None, "--rev", help="Repo revision to use", show_default=True)
-option_repo = Option(".", "-r", "--repo", help="Repository to use", show_default=True)
+option_repo = Option(
+    ".",
+    "-r",
+    "--repo",
+    help="Repository to use",
+    show_default=True,
+)
 option_all_branches = Option(
     False,
     "-a",
@@ -559,16 +565,16 @@ def assign(
 
     Examples:
         Assign "nn" to "prod" at specific ref:
-        $ gto assign nn prod abcd123
+        $ gto assign nn abcd123 --stage prod
 
         Assign specific version:
-        $ gto assign nn prod --version v1.0.0
+        $ gto assign nn --version v1.0.0 --stage prod
 
         Assign at specific ref and name version explicitly:
-        $ gto assign nn prod abcd123 --version v1.0.0
+        $ gto assign nn abcd123 --version v1.0.0 --stage prod
 
-        Assign without increment
-        $ gto assign nn prod HEAD --simple
+        Assign without increment:
+        $ gto assign nn HEAD --stage prod --simple
     """
     if ref is not None:
         name_version = version
@@ -728,7 +734,7 @@ def show(  # pylint: disable=too-many-locals
     versions_per_stage: int = option_versions_per_stage,
     sort: str = option_sort,
 ):
-    """Show the registry state
+    """Show the registry state, highest version, or what's assigned in stage
 
     Examples:
         Show the registry:
@@ -740,10 +746,6 @@ def show(  # pylint: disable=too-many-locals
         Show greatest version or what's in stage:
         $ gto show nn@greatest
         $ gto show nn#prod
-
-        Use --all-branches and --all-commits to read more than just HEAD:
-        $ gto show --all-branches
-        $ gto show nn --all-commits
     """
     show_options = [show_name, show_version, show_stage, show_ref]
     assert (
